@@ -7,7 +7,7 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
     
     deparse(model$call$random) else
       
-      if(any(class(model) %in% c("lmerMod", "merModLmerTest", "glmerMod")))
+      if(any(class(model) %in% c("lmerMod", "merModLmerTest", "glmerMod", "glmmTMB")))
         
         paste("(", findbars(formula(model)), ")", collapse = " + ")
   
@@ -28,7 +28,7 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
     
     } else 
       
-      if(any(class(model) %in% c("lmerMod", "merModLmerTest", "glmerMod")))
+      if(any(class(model) %in% c("lmerMod", "merModLmerTest", "glmerMod", "glmmTMB")))
         
         sapply(strsplit(random.formula, ".\\+.")[[1]], function(x)
           
@@ -37,7 +37,7 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
           )
   
   # Get random slopes in the model list, otherwise return vector of terms to drop
-  random.slopes = if(any(class(model) %in% c("lme", "glmmPQL", "glmerMod", "merModLmerTest", "glmmadmb"))) 
+  random.slopes = if(any(class(model) %in% c("lme", "glmmPQL", "glmerMod", "merModLmerTest", "glmmadmb", "glmmTMB"))) 
     
     if(is.null(dropterms)) {
       
@@ -47,7 +47,7 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
           
           unlist(lapply(modelList[[j]]$coefficients$random, function(k) colnames(k)))
         
-        else if(any(class(modelList[[j]]) %in% c("lme", "glmerMod", "merModLmerTest", "glmmadmb"))) 
+        else if(any(class(modelList[[j]]) %in% c("lme", "glmerMod", "merModLmerTest", "glmmadmb", "glmmTMB"))) 
           
           unlist(lapply(ranef(modelList[[j]]), function(k) colnames(k)))
         
@@ -60,7 +60,7 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
   # Define new random slopes 
   new.random.slopes = random.slopes[which(random.slopes %in% unlist(strsplit(rhs, ".\\+.")))]
   
-  if(length(new.random.slopes) == 0) new.random.slopes = 1
+  if(length(new.random.slopes) == 0) new.random.slopes = 1 else new.random.slopes = paste0(new.random.slopes, collapse = " + ")
   
   # Replace random slopes if any variables in model formula appear in random slopes  
   if(length(random.slopes) != 0) {
@@ -69,27 +69,23 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
       
       if(is.list(random.structure)) {
         
-        names(random.structure) = gsub(" ", "", unlist(random.structure))
+        lapply(random.structure, function(x) formula(gsub("(.*)\\|", paste("~", new.random.slopes, "|"), x)) ) 
         
-        for(i in 1:length(random.structure)) random.structure[[i]] = formula(paste("~ ", new.random.slopes))
-        
-        random.structure
-        
-      } else {
+        } else {
         
         formula(
           paste("~ ", 
-                paste(new.random.slopes, collapse = " + "),
+                new.random.slopes,
                 " | ",
                 random.structure) 
         )
     
-    } else if(any(class(model) %in% c("glmerMod", "merModLmerTest")))
+    } else if(any(class(model) %in% c("glmerMod", "merModLmerTest", "glmmTMB")))
       
       # formula(
         paste(
           sapply(random.structure, function(x)
-            paste("(", paste(new.random.slopes, collapse = " + "), " | ", x, ")") ),
+            paste("(", new.random.slopes, " | ", x, ")") ),
           collapse = " + ")
       # )
     
@@ -97,11 +93,7 @@ get.random.formula = function(model, rhs, modelList, dropterms = NULL) {
       
       if(is.list(random.structure)) {
         
-        names(random.structure) = gsub(" ", "", unlist(random.structure))
-        
-        for(i in 1:length(random.structure)) random.structure[[i]] = formula("~ 1")
-        
-        random.structure
+        lapply(random.structure, function(x) formula(gsub("(.*)\\|", paste("~", new.random.slopes, "|"), x)) ) 
         
       } else if(any(class(model) %in% c("lme", "glmmPQL"))) formula(random.formula)
     
