@@ -1,5 +1,7 @@
 get.scaled.data = function(modelList, data, standardize) {
 
+  if(is.null(data)) stop("Must supply data if calculating standardized coefficients!")
+  
   if(any(sapply(modelList, class) == "pgls") | class(data) == "comparative.data") {
     
     # Extract data.frame
@@ -70,6 +72,11 @@ get.scaled.data = function(modelList, data, standardize) {
   # Remove variables that are factors
   vars.to.scale = vars.to.scale[!vars.to.scale %in% colnames(data)[sapply(data, function(x) any(is.factor(x) | is.character(x)))] ]
   
+  # Convert variables that are factors to numeric
+  # data[, sapply(data, function(x) any(is.factor(x) | is.character(x)))] = 
+  #   
+  #   apply(data[, sapply(data, function(x) any(is.factor(x) | is.character(x))), drop = FALSE], 2, function(x) as.numeric(as.factor(x)))
+  
   # Remove variables that appear as random effects
   rand.mods = which(sapply(modelList, class) %in% c("lme", "lmerMod", "merModLmerTest", "glmerMod"))
  
